@@ -11,8 +11,7 @@ namespace __dispatch__
 {
 
   template <class Any, class... Arg0>
-  auto update(Any &&any, Arg0 &&...arg0)
-      -> decltype(any.update(std::forward<Arg0>(arg0)...))
+  auto update(Any &&any, Arg0 &&...arg0) -> decltype(any.update(std::forward<Arg0>(arg0)...))
   {
     return any.update(std::forward<Arg0>(arg0)...);
   }
