@@ -24,16 +24,14 @@ namespace builtins
     types::static_list<T, N> static_list(types::array_tuple<T, N> &&other);
 
     template <class T>
-    auto static_list(T &&other) -> decltype(pythonic::builtins::functor::list{}(
-                                    std::forward<T>(other)));
+    auto static_list(T &&other)
+        -> decltype(pythonic::builtins::functor::list{}(std::forward<T>(other)));
 
     template <class T0, class... Tys>
-    types::static_list<typename __combined<T0, Tys...>::type,
-                       1 + sizeof...(Tys)>
+    types::static_list<typename __combined<T0, Tys...>::type, 1 + sizeof...(Tys)>
     static_list(std::tuple<T0, Tys...> const &other)
     {
-      return static_list(
-          types::to_array<typename __combined<T0, Tys...>::type>(other));
+      return static_list(types::to_array<typename __combined<T0, Tys...>::type>(other));
     }
 
     DEFINE_FUNCTOR(pythonic::builtins::pythran, static_list);
