@@ -12,8 +12,7 @@ namespace numpy
   template <class E, class dtype>
   struct _asarray {
     template <class... Types>
-    auto operator()(Types &&...args)
-        -> decltype(array(std::forward<Types>(args)...));
+    auto operator()(Types &&...args) -> decltype(array(std::forward<Types>(args)...));
   };
 
   template <class T, class pS>
@@ -24,15 +23,12 @@ namespace numpy
 
   template <class E>
   auto asarray(E &&e, types::none_type d = types::none_type())
-      -> decltype(_asarray<typename std::decay<E>::type,
-                           typename types::dtype_of<
-                               typename std::decay<E>::type>::type>{}(
+      -> decltype(_asarray<std::decay_t<E>, typename types::dtype_of<std::decay_t<E>>::type>{}(
           std::forward<E>(e)));
 
   template <class E, class dtype>
   auto asarray(E &&e, dtype d)
-      -> decltype(_asarray<typename std::decay<E>::type,
-                           typename dtype::type>{}(std::forward<E>(e), d));
+      -> decltype(_asarray<std::decay_t<E>, typename dtype::type>{}(std::forward<E>(e), d));
 
   DEFINE_FUNCTOR(pythonic::numpy, asarray);
 } // namespace numpy
