@@ -12,14 +12,12 @@ namespace numpy
   namespace random
   {
     template <class pS>
-    types::ndarray<double, pS> gumbel(double loc, double scale,
-                                      pS const &shape);
+    types::ndarray<double, pS> gumbel(double loc, double scale, pS const &shape);
 
     auto gumbel(double loc, double scale, long size)
         -> decltype(gumbel(loc, scale, types::array_tuple<long, 1>{{size}}));
 
-    double gumbel(double loc = 0.0, double scale = 1.0,
-                  types::none_type size = {});
+    double gumbel(double loc = 0.0, double scale = 1.0, types::none_type size = {});
 
     DEFINE_FUNCTOR(pythonic::numpy::random, gumbel);
   } // namespace random
