@@ -17,8 +17,7 @@ namespace types
       return Val;
     }
 
-    template <class U, U Wal,
-              class _ = typename std::enable_if<Val == (T)Wal, void>::type>
+    template <class U, U Wal, class _ = std::enable_if_t<Val == (T)Wal, void>>
     immediate(std::integral_constant<U, Wal>)
     {
     }
