@@ -23,10 +23,9 @@ namespace numpy
     void _flatnonzero(I begin, I end, O &out, long &i, utils::int_<N>)
     {
       for (; begin != end; ++begin)
-        _flatnonzero((*begin).begin(), (*begin).end(), out, i,
-                     utils::int_<N - 1>());
+        _flatnonzero((*begin).begin(), (*begin).end(), out, i, utils::int_<N - 1>());
     }
-  }
+  } // namespace
   template <class E>
   types::ndarray<long, types::pshape<long>> flatnonzero(E const &expr)
   {
@@ -38,7 +37,7 @@ namespace numpy
     types::pshape<long> shape = iter - buffer->data;
     return types::ndarray<long, types::pshape<long>>(std::move(buffer), shape);
   }
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
