@@ -25,9 +25,7 @@ namespace numpy
   } // namespace
 
   template <class E, class S>
-  typename std::enable_if<
-      std::is_scalar<E>::value,
-      types::array_tuple<long, std::tuple_size<S>::value>>::type
+  std::enable_if_t<std::is_scalar<E>::value, types::array_tuple<long, std::tuple_size<S>::value>>
   unravel_index(E const &expr, S const &shape, types::str const &order)
   {
     types::array_tuple<long, std::tuple_size<S>::value> ret;
