@@ -11,8 +11,7 @@ PYTHONIC_NS_BEGIN
 namespace operator_
 {
   template <class A, class B>
-  auto contains(A &&a,
-                B &&b) -> decltype(in(std::forward<A>(a), std::forward<B>(b)))
+  auto contains(A &&a, B &&b) -> decltype(in(std::forward<A>(a), std::forward<B>(b)))
   {
     return in(std::forward<A>(a), std::forward<B>(b));
   }
