@@ -11,11 +11,9 @@ namespace operator_
 {
 
   template <class A, class B>
-  auto mod(A &&a, B &&b) ->
-      typename std::enable_if<
-          std::is_fundamental<typename std::decay<A>::type>::value &&
-              std::is_fundamental<typename std::decay<B>::type>::value,
-          decltype(std::forward<A>(a) % std::forward<B>(b))>::type
+  auto mod(A &&a, B &&b) -> std::enable_if_t<std::is_fundamental<std::decay_t<A>>::value &&
+                                                 std::is_fundamental<std::decay_t<B>>::value,
+                                             decltype(std::forward<A>(a) % std::forward<B>(b))>
   {
     auto t = std::forward<A>(a) % b;
     return t < 0 ? (t + b) : t;
@@ -35,10 +33,9 @@ namespace operator_
 
   template <class A, class B>
   auto mod(A &&a, B &&b) // for ndarrays
-      -> typename std::enable_if<
-          !std::is_fundamental<typename std::decay<A>::type>::value ||
-              !std::is_fundamental<typename std::decay<B>::type>::value,
-          decltype(std::forward<A>(a) % std::forward<B>(b))>::type
+      -> std::enable_if_t<!std::is_fundamental<std::decay_t<A>>::value ||
+                              !std::is_fundamental<std::decay_t<B>>::value,
+                          decltype(std::forward<A>(a) % std::forward<B>(b))>
   {
     return std::forward<A>(a) % std::forward<B>(b);
   }
