@@ -22,16 +22,15 @@ namespace scipy
       double jv(T0 x, T1 y)
       {
         using namespace boost::math::policies;
-        return boost::math::cyl_bessel_j(x, y,
-                                         make_policy(promote_double<true>()));
+        return boost::math::cyl_bessel_j(x, y, make_policy(promote_double<true>()));
       }
-    }
+    } // namespace details
 
 #define NUMPY_NARY_FUNC_NAME jv
 #define NUMPY_NARY_FUNC_SYM details::jv
 #include "pythonic/types/numpy_nary_expr.hpp"
-  }
-}
+  } // namespace special
+} // namespace scipy
 PYTHONIC_NS_END
 
 #endif
